/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder;

import java.applet.Applet;

import java.awt.Frame;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import java.io.File;

import chtdecoder.datastructures.CHTCode;
import chtdecoder.datastructures.CHTCodeIterator;

import chtdecoder.exceptions.CHTFileException;

import chtdecoder.tools.AbstractCHTFileReader;

import chtdecoder.view.CHTApplet;

/**
 * The main run class for the CHTDecoder program.
 *
 * @author John David Ratliff
 * @version 1.2, 09/14/04
 */
public class CHTDecoder {
    /**
     * The name String.
     */
    public static final String APP_NAME = "CHTDecoder";

    /**
     * The version String.
     */
    public static final String APP_VERSION = "1.0";

    /**
     * The copyright String.
     */
    public static final String APP_COPYRIGHT = "Copyright (C) 2004 emuWorks";

    /**
     * The default frame width.
     */
    public static final int APP_WIDTH = 640;

    /**
     * The default frame height.
     */
    public static final int APP_HEIGHT = 480;

    /**
     * Starts the application. Run with 0 arguments for GUI mode, or 1 or
     * more .CHT file arguments for text mode.
     *
     * @param args 0 args for GUI mode, &gt; 0 args for text mode.
     */
    public static void main(String[] args) {
        if (args.length == 0) {
            Frame frame = new Frame(APP_NAME + " " + APP_VERSION);
            Applet applet = new CHTApplet(frame);

            applet.init();
            applet.start();

            frame.addWindowListener(new WindowAdapter() {
                    public void windowClosing(WindowEvent event) {
                        System.exit(0);
                    }
                });
            frame.add(applet);
            frame.setSize(APP_WIDTH, APP_HEIGHT);
            frame.show();
        } else {
            for (int i = 0; i < args.length; i++) {
                File file = new File(args[i]);

                try {
                    CHTCodeIterator iterator = AbstractCHTFileReader.readCHTFile(file);

                    while (iterator.hasMore()) {
                        CHTCode code = iterator.next();
                        System.out.println(code);
                    }
                } catch (CHTFileException e) {
                    System.err.println("error: " + e);
                }
            }
        }
    }
}
